CLI
===

Here you can find the itwinai CLI reference.

.. cli_reference.md must be generated by typer using:
.. $ typer itwinai.cli  utils docs --output docs/api/cli.md
.. More info: https://typer.tiangolo.com/tutorial/package/#generate-docs

.. include:: cli.md
   :parser: myst_parser.sphinx_
   :start-line: 2